==> savane-1.0.2.tar.gz: savane/frontend/php/docs/admin.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: admin.php,v 1.20 2004/03/13 18:22:05 yeupou Exp $
#
#  Copyright 2002-2004 (c) Mathieu Roy <yeupou@gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";    

$project=project_get_object($sys_group_id);
$title = $project->getPublicName().': '._("Admin documentation");

site_project_header(array('title'=>$title,'group'=>$sys_group_id,'toptab'=>'special'));

# we get *.html content and we show only <body>content</body>

# Currently not advertised: with the local option in the link, it will print
# the content of a file in set by sys_localdoc_file, if exiting.
# If this file exists, it will show up in the menu links too.

if ($local && $GLOBALS['sys_localdoc_file']) 
{
  print utils_remove_htmlheader(utils_read_file($GLOBALS['sys_localdoc_file']));
}
else 
{
  print utils_remove_htmlheader(utils_read_file($sys_urlroot."/docs/savannah.html"));
}

$HTML->footer(array());

?>

==> savane-1.0.4.tar.gz: savane/frontend/php/docs/admin.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: admin.php,v 1.21 2004/06/11 12:52:48 yeupou Exp $
#
#  Copyright 2002-2004 (c) Mathieu Roy <yeupou@gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../include/pre.php";    

$project=project_get_object($sys_group_id);
$title = $project->getPublicName().': '._("Admin documentation");

site_admin_header(array('title'=>$title,'group'=>$sys_group_id,'toptab'=>'special'));

# we get *.html content and we show only <body>content</body>

# Currently not advertised: with the local option in the link, it will print
# the content of a file in set by sys_localdoc_file, if exiting.
# If this file exists, it will show up in the menu links too.

if ($local && $GLOBALS['sys_localdoc_file']) 
{
  print utils_remove_htmlheader(utils_read_file($GLOBALS['sys_localdoc_file']));
}
else 
{
  print utils_remove_htmlheader(utils_read_file($sys_urlroot."/docs/savannah.html"));
}

$HTML->footer(array());

?>
